@@ -10,12 +10,15 @@ KCrontab::KCrontab(const char *)
 
   config = kapp->getConfig();
 
-  setupToolBar();
   setupStatusBar();
+  setupToolBar();
   setupMenuBar();
-  setupAccelerators();
   setupData();
- 
+
+  timer = new QTimer(this);
+  connect(timer, SIGNAL(timeout()),
+          this, SLOT(slotClearStatusBar()));
+
   /* ********************************************************************** */
  
   frMain = new QFrame(this, "frMain");
@@ -26,7 +29,7 @@ KCrontab::KCrontab(const char *)
   khead = new KHeader(frMain, "khead", 8, KHeader::Resizable);
   khead->setMinimumSize(560, 20);
 
-  khead->setHeaderLabel(0, "*", AlignLeft | AlignVCenter);
+  khead->setHeaderLabel(0, "+", AlignLeft | AlignVCenter);
   khead->setHeaderLabel(1, i18n("Hour"), AlignLeft | AlignVCenter);
   khead->setHeaderLabel(2, i18n("Minute"), AlignLeft | AlignVCenter);
   khead->setHeaderLabel(3, i18n("Day"), AlignLeft | AlignVCenter);
@@ -42,13 +45,16 @@ KCrontab::KCrontab(const char *)
   crontable->setAutoDelete(TRUE);
   crontable->setUser(user);
 
-  connect(crontable, SIGNAL(doubleClick()),
-          this, SLOT(slotEdit()));
   connect(khead, SIGNAL(sizeChanged(int, int)),
           crontable, SLOT(setColumnWidth(int, int)));
   connect(crontable, SIGNAL(hSliderMoved(int)),
           khead, SLOT(setOrigin(int)));
 
+  connect(crontable, SIGNAL(doubleClick()),
+          this, SLOT(slotEdit()));
+  connect(crontable, SIGNAL(changeState()),
+          this, SLOT(slotChangeState()));
+
   config->setGroup(kapp->appName());  
   QString s;
   int     n;
@@ -103,6 +109,7 @@ KCrontab::KCrontab(const char *)
 KCrontab::~KCrontab()
 {
   delete userList;
+  delete timer;
 
   delete statusbar;
   delete toolbar;
@@ -122,39 +129,41 @@ void KCrontab::closeEvent(QCloseEvent *e)
 
 void KCrontab::setupMenuBar()
 {
+  KStdAccel stdaccel(config);
+  int       n;
+
   file    = new QPopupMenu;
   edit    = new QPopupMenu;
   options = new QPopupMenu;
-  help    = kapp->getHelpMenu(FALSE, "kcrontab 0.1.7\n\n" 
+  help    = kapp->getHelpMenu(FALSE, "kcrontab 0.2.2\n\n" 
 	                      "(c) by Michael Bialas <michael@quinto.ruhr.de>\n"
                               "and David Klemm <klemm@abacus.at>");
-	
+			      
   file->insertItem(i18n("&New crontab"),
-                   this, SLOT(slotNew()));
+                   this, SLOT(slotNew()), stdaccel.openNew());
   file->insertItem(i18n("&Read crontab"),
-                   this, SLOT(slotRead()));
+                   this, SLOT(slotRead()), stdaccel.open());
   if (getuid() == 0)
     file->insertItem(i18n("Read &system crontab"),
                      this, SLOT(slotReadSystem()));
   file->insertItem(i18n("&Write crontab"),
-                   this, SLOT(slotWrite()));
+                   this, SLOT(slotWrite()), stdaccel.save());
   file->insertSeparator();
   file->insertItem(i18n("E&xit"),
-                   this, SLOT(slotExit()));
+                   this, SLOT(slotExit()), stdaccel.quit());
 
   edit->insertItem(i18n("&Add Entry"),
-                   this, SLOT(slotAdd()));
+                   this, SLOT(slotAdd()), Key_Insert);
   edit->insertItem(i18n("&Edit Entry"),
-                   this, SLOT(slotEdit()));
+                   this, SLOT(slotEdit()), Key_Return);
   edit->insertItem(i18n("&Remove Entry"),
-                   this, SLOT(slotRemove()));
+                   this, SLOT(slotRemove()), Key_Delete);
   edit->insertSeparator();
   edit->insertItem(i18n("Edit &Variables"),
-                   this, SLOT(slotVariable()));
+                   this, SLOT(slotVariable()), ALT + Key_V);
+
+  config->setGroup(kapp->appName());
 
-  config->setGroup (kapp->appName());
-  int n;
-  
   n = config->readNumEntry ("Hide_Toolbar");
   if (!n) 
     hide_toolbar = FALSE;	
@@ -258,11 +267,9 @@ void KCrontab::setupToolBar()
 
 void KCrontab::setupStatusBar()
 {
-
   config->setGroup(kapp->appName());
-  int n;
 
-  n = config->readNumEntry("Hide_Statusbar");
+  int n = config->readNumEntry("Hide_Statusbar");
   if (!n) 
     hide_statusbar = FALSE;
   else
@@ -274,21 +281,6 @@ void KCrontab::setupStatusBar()
   setStatusBar(statusbar);
 }
 
-void KCrontab::setupAccelerators()
-{
-  KStdAccel stdaccel(kapp->getConfig());
-  accel = new QAccel(this);
-
-  accel->connectItem(accel->insertItem(stdaccel.quit()),
-                     kapp, SLOT(quit()));
-  accel->connectItem(accel->insertItem(stdaccel.openNew()),
-                     this, SLOT(slotNew()));
-  accel->connectItem(accel->insertItem(stdaccel.open()),
-                     this, SLOT(slotRead()));
-  accel->connectItem(accel->insertItem(stdaccel.save()),
-                     this, SLOT(slotWrite()));
-}
-
 void KCrontab::setupData()
 {
   struct passwd *pw;
@@ -328,6 +320,7 @@ void KCrontab::slotNew()
             crontable->repaint();
             variables.clear();
             statusbar->changeItem(i18n("New crontab..."), 0);
+	    timer->start(WAIT, TRUE);
             break;
 
     case 1:
@@ -353,6 +346,7 @@ void KCrontab::slotWrite()
   {
     statusbar->changeItem(i18n("Write cancelled, because the edit " \
                                "variables dialog is open."), 0);
+    timer->start(WAIT, TRUE);
     return;
   }
 
@@ -363,6 +357,7 @@ void KCrontab::slotWrite()
     {
       statusbar->changeItem(i18n("Write cancelled, because an edit entry " \
                                  "dialog is open."), 0);
+      timer->start(WAIT, TRUE);
       return;
     }
   }
@@ -391,6 +386,7 @@ void KCrontab::slotWrite()
   if (syscron)
   {
     statusbar->changeItem(i18n("Crontab written..."), 0);
+    timer->start(WAIT, TRUE);
     return;
   }
 
@@ -402,7 +398,10 @@ void KCrontab::slotWrite()
     QMessageBox::critical(this, kapp->appName(), 
                           i18n("Could not start \"crontab\"."));
   else
-   statusbar->changeItem(i18n("Crontab written..."), 0);
+  {
+    statusbar->changeItem(i18n("Crontab written..."), 0);
+    timer->start(WAIT, TRUE);
+  }
   
   unlink(tmpFilePath.data());
 }
@@ -435,6 +434,7 @@ void KCrontab::slotExit()
 void KCrontab::slotAdd()
 {
   statusbar->changeItem(i18n("Adding an entry..."), 0);
+  timer->start(WAIT, TRUE);
 
   edEntry = new EditEntry(syscron);
   edEntry->setUser(userList, user);
@@ -458,6 +458,7 @@ void KCrontab::slotEdit()
   if (!row->isEdited())
   {
     statusbar->changeItem(i18n("Editing an entry..."), 0);
+    timer->start(WAIT, TRUE);
 
     edEntry = new EditEntry(syscron, row);
     edEntry->setUser(userList, user);
@@ -466,7 +467,10 @@ void KCrontab::slotEdit()
     edEntry->show();
   }
   else
+  {
     statusbar->changeItem(i18n("Editing in progress."), 0);
+    timer->start(WAIT, TRUE);
+  }
 }
 
 void KCrontab::slotRemove()
@@ -476,6 +480,7 @@ void KCrontab::slotRemove()
   if (index == -1)
   {
     statusbar->changeItem(i18n("Select an entry first."), 0);
+    timer->start(WAIT, TRUE);
     return;
   }
 
@@ -484,6 +489,7 @@ void KCrontab::slotRemove()
   {
     statusbar->changeItem(i18n("Current entry is edited, " \
                                "so it could not be deleted."), 0);
+    timer->start(WAIT, TRUE);  
     return;
   }
 
@@ -496,6 +502,7 @@ void KCrontab::slotVariable()
   if (!editVariables)
   {
     statusbar->changeItem(i18n("Editing variables..."), 0);
+    timer->start(WAIT, TRUE);
 
     editVariables = TRUE;
 
@@ -537,7 +544,7 @@ void KCrontab::slotToggleStatusBar()
   }
 }
 
-void KCrontab::slotSaveSettings ()
+void KCrontab::slotSaveSettings()
 {
   config->setGroup(kapp->appName());
   config->writeEntry("Width", width());
@@ -548,10 +555,13 @@ void KCrontab::slotSaveSettings ()
   QString s;
   for (int i = 0; i <= khead->numHeaders() - 1; i++)
   {
-      s.sprintf("Header%d", i);
-      config->writeEntry(s, khead->getHeaderSize(i));
+    s.sprintf("Header%d", i);
+    config->writeEntry(s, khead->getHeaderSize(i));
   }
   config->sync();
+
+  statusbar->changeItem(i18n("Settings saved."), 0);
+  timer->start(WAIT, TRUE);    
 }
 
 void KCrontab::slotHelp()
@@ -578,6 +588,16 @@ void KCrontab::slotVariableClose(bool _changed)
   editVariables = FALSE;
 }
 
+void KCrontab::slotClearStatusBar()
+{
+  statusbar->changeItem("", 0);
+}
+
+void KCrontab::slotChangeState()
+{
+  changed = TRUE;
+}
+
 void KCrontab::readCrontab(bool _syscron)
 {
   QString fname;
@@ -589,6 +609,7 @@ void KCrontab::readCrontab(bool _syscron)
   {
     statusbar->changeItem(i18n("Read cancelled, because the edit " \
                                "variables dialog is open."), 0);
+    timer->start(WAIT, TRUE);
     return;
   }
 
@@ -599,6 +620,7 @@ void KCrontab::readCrontab(bool _syscron)
     {
       statusbar->changeItem(i18n("Read cancelled, because an edit entry " \
                                  "dialog is open."), 0);
+      timer->start(WAIT, TRUE);
       return;
     }
   }
@@ -609,6 +631,7 @@ void KCrontab::readCrontab(bool _syscron)
              "Are you sure?"), i18n("OK"), i18n("Cancel"), 0, 1))
     {
       statusbar->changeItem(i18n("Read cancelled."), 0);
+      timer->start(WAIT, TRUE);
       return;
     } 
 
@@ -688,7 +711,10 @@ void KCrontab::readCrontab(bool _syscron)
     }
   }
   else if (ret != 256)
+  {
     statusbar->changeItem(i18n("Error while reading crontab."), 0);
+    timer->start(WAIT, TRUE);
+  }
 
   if (!syscron)
   {
@@ -702,8 +728,13 @@ void KCrontab::readCrontab(bool _syscron)
   if (crontable->count() > 0)
   {
     statusbar->changeItem(i18n("Crontab read."), 0);
+    timer->start(WAIT, TRUE);
+
     crontable->setCurrentItem(0);
   }
   else
+  {
     statusbar->changeItem(i18n("Crontab is empty."), 0);
+    timer->start(WAIT, TRUE);
+  }
 }
